#!/bin/bash
#packager:	Rémi Descard <remed> (remi~dot~descard~at~gmail~dot~com)
#source: http://prdownloads.sourceforge.net/wesnoth/wesnoth-1.8.2.tar.bz2

softname=wesnoth
softversion=1.8.2
zenversion=66
pkgversion=1

# This is a heavy game so we're not going to compile it for i486
arch=i686 
cpu=i686

prefix=/usr

#log
(

#parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$zenversion.$pkgversion"
dest="$buildir/$package"


# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
wesnoth: (Turn based strategy game)
wesnoth: The Battle for Wesnoth is a turn-based strategy game with a fantasy
wesnoth: theme. Build up a great army, gradually turning raw recruits into
wesnoth: hardened veterans.  In later games, recall your toughest warriors and
wesnoth: form a deadly host against whom none can stand! Choose units from a
wesnoth: large pool of specialists, and hand-pick a force with the right
wesnoth: strengths to fight well on different terrains against all manner of
wesnoth: opposition.
EOF
#extract the source code
cd $buildir 
tar xfvj $srcpkg
cd $src

#build
	export CFLAGS="-O2 -march=$arch -mtune=$cpu"
	export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

	./autogen.sh

	./configure \
	--prefix=$prefix \
	--sysconfdir=/etc \
	--localstatedir=/var \
	--mandir=/usr/man \
	--docdir=/usr/doc/$softname-$softversion \
	--build=$arch-slackware-linux \
	--enable-server \
	--enable-campaign-server \
	--enable-editor \
	--with-x

# speed up the build 
JOBS="-j3"
make $JOBS
make install DESTDIR=$dest

# move icons to the right place
mkdir -p $dest/usr/share/icons/hicolor/64x64/apps
mv $dest/usr/share/icons/wesnoth*.png $dest/usr/share/icons/hicolor/64x64/apps

#defaults files
cp -a \
		ABOUT-NLS COPYING INSTALL README changelog copyright players_changelog \
		$dest/usr/doc/$softname-$softversion
		
#compress man pages
find $dest/usr/man -type f -exec gzip -9 {} \;

#Strip
( cd $dest
 find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
 find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion/


# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

# log 
) 2>&1 | tee "$softname-$softversion-build.log"
